# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import setuptools

setuptools.setup(
    name="ad_ci_tools",
    version='0.1.0',
    author="Rotaru Sergey",
    author_email="rsv@arenadata.io",
    description="Ci library with miscellaneous utils",
    url="https://github.com/arenadata/ci_tools",
    packages=setuptools.find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=[
        'gitpython', 'wheel'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



from git import Repo


class JenkinsRepo(Repo):

    def get_git_data(self):
        """
            Return git repo data.
            In case of branch retun {branch: _name_}
            In case of pr return {pull_request: _number_}
        """

        describe = self.git.describe('--all')
        describe_list = describe.split('/')
        reponame = self.remotes.origin.url.split('/')[-1].split('.git')[0]
        repoowner = self.remotes.origin.url.split('/')[-2].split('.com:')[-1]

        data = {'reponame': reponame, 'repoowner': repoowner}
        # pull request case
        # it works basically on ci with
        # clean git init and fetch remote with +refs/pull/*:refs/origin/pr/*
        # in onther cases with high chance it wont detect pr
        if describe_list[1] == 'pr' and len(describe_list) > 2:
            data.update({'pull_request': describe_list[2]})
            return data
        # tags case
        if describe_list[0] == 'tags':
            branch = next(filter(
                lambda x: 'origin' in x,
                self.git.branch('-a', '--contains', describe).splitlines())).split('/')[2]
        # all others case
        else:
            try:
                branch = describe_list[2]
            except IndexError:
                branch = self.git.rev_parse('--abbrev-ref', 'HEAD')

        data.update({'branch': branch})
        return data
